create database IBQUOTA;
grant all privileges on IBQUOTA.* to ibquota@localhost identified by 'ibquota';
use IBQUOTA;

CREATE TABLE conjunto_impressora (
  cod_conjunto_impressora INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cod_impressora INTEGER UNSIGNED NOT NULL,
  valor_impressao FLOAT NOT NULL DEFAULT '1.00',
  cod_politica INTEGER UNSIGNED NULL,
  PRIMARY KEY(cod_conjunto_impressora),
  INDEX conjunto_impressora_FKIndex1(cod_impressora),
  INDEX conjunto_impressora_FKIndex2(cod_politica)
);

CREATE TABLE formato (
  cod_formato INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  nome_formato VARCHAR(50) NULL,
  PRIMARY KEY(cod_formato)
);
INSERT INTO formato VALUES (1,"NONE");
INSERT INTO formato VALUES (2,"PS-PostScritp");
INSERT INTO formato VALUES (3,"PCL");
INSERT INTO formato VALUES (4,"PCL3GUI");
INSERT INTO formato VALUES (5,"PCLXL");

CREATE TABLE grupo (
  cod_grupo INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  nome_grupo VARCHAR(50) NOT NULL,
  PRIMARY KEY(cod_grupo),
  UNIQUE INDEX idx_grupoUnico(nome_grupo)
);

CREATE TABLE impressoes (
  cod_impressoes INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cod_status_impressao INTEGER UNSIGNED NOT NULL,
  cod_impressora INTEGER UNSIGNED NOT NULL,
  cod_usuario INTEGER UNSIGNED NOT NULL,
  data_impressao DATE NOT NULL,
  hora_impressao TIME NOT NULL,
  job_numero INTEGER UNSIGNED NOT NULL,
  nome_documento VARCHAR(100) NOT NULL,
  paginas INTEGER UNSIGNED NOT NULL,
  estacao VARCHAR(50) NULL,
  cod_formato INTEGER UNSIGNED NULL,
  cod_politica INTEGER UNSIGNED NULL,
  PRIMARY KEY(cod_impressoes),
  INDEX impressoes_FKIndex1(cod_usuario),
  INDEX impressoes_FKIndex2(cod_impressora),
  INDEX impressoes_FKIndex3(cod_status_impressao),
  INDEX impressoes_FKIndex4(cod_formato),
  INDEX impressoes_FKIndex5(cod_politica)
);

CREATE TABLE impressora (
  cod_impressora INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  nome_impressora VARCHAR(12) NOT NULL,
  descricao_impressora VARCHAR(50) NOT NULL,
  fila_real VARCHAR(100) NOT NULL,
  fila_virtual VARCHAR(100) NOT NULL,
  path_spool VARCHAR(250) NOT NULL,
  PRIMARY KEY(cod_impressora),
  UNIQUE INDEX idx_nomeImpressora(nome_impressora)
);

CREATE TABLE inicializacao (
  cod_inicializacao INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  dia INTEGER UNSIGNED NULL,
  mes INTEGER UNSIGNED NULL,
  cod_politica INTEGER UNSIGNED NULL,
  PRIMARY KEY(cod_inicializacao),
  INDEX inicializacao_FKIndex1(cod_politica)
);

CREATE TABLE modp (
  cod_modp INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cod_usuario INTEGER UNSIGNED NOT NULL,
  quota FLOAT NOT NULL,
  cod_politica INTEGER UNSIGNED NULL,
  PRIMARY KEY(cod_modp),
  INDEX modpd_FKIndex1(cod_usuario),
  INDEX modpd_FKIndex2(cod_politica)
);

CREATE TABLE politica (
  cod_politica INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cod_tipo_politica INTEGER UNSIGNED NOT NULL,
  cod_grupo INTEGER UNSIGNED NOT NULL,
  quota_acumulativa BOOL NOT NULL  DEFAULT '0',
  quota_infinita BOOL NOT NULL  DEFAULT '0',
  arquivo_banner VARCHAR(250) NULL,
  contabiliza_banner BOOL NOT NULL DEFAULT '0',
  quota_padrao FLOAT,
  PRIMARY KEY(cod_politica),
  INDEX politica_FKIndex1(cod_grupo),
  INDEX politica_FKIndex2(cod_tipo_politica)
);

CREATE TABLE status_impressao (
  cod_status_impressao INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  nome_status VARCHAR(100) NOT NULL,
  erro BOOL NULL,
  PRIMARY KEY(cod_status_impressao)
);
INSERT INTO status_impressao (nome_status,erro) VALUES ("OK - Impresso com sucesso",0);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Usurio no cadastrado",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Usurio sem quota",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Arquivo temporrio de impresso no encontrado",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Formato de arquivo no PS (postscript)",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Formato de arquivo no PCL",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("No foi possvel determinar quantidade de pginas",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Usuario com Quota insuficiente",1);
INSERT INTO status_impressao (nome_status,erro) VALUES ("Funo da tabela de modulos de impresso inexistente",1); 

CREATE TABLE tipo_politica (
  cod_tipo_politica INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  nome_tipo_politica VARCHAR(50) NOT NULL,
  descricao_tipo_politica VARCHAR(100) NOT NULL,
  funcao_perl VARCHAR(50) NOT NULL,
  arquivo_perl VARCHAR(100) NOT NULL,
  tabela_modulo_perl VARCHAR(100) NOT NULL,
  quota_acumulativa BOOL NOT NULL DEFAULT '0',
  quota_infinita BOOL NOT NULL DEFAULT '0',
  banner BOOL NOT NULL DEFAULT '0',
  autor_modulo VARCHAR(50) NULL,
  email_autor_modulo VARCHAR(50) NULL,
  PRIMARY KEY(cod_tipo_politica),
  UNIQUE INDEX idx_nome_tipo_politica(nome_tipo_politica)
);
INSERT INTO tipo_politica VALUES (1,"Padro","Tipo de politica padro","","","modp",1,1,1,"Valcir C.",
                                  "valcir@unicamp.br");
INSERT INTO tipo_politica VALUES (2,"Centro de Custo","Atribui uma quota a um grupo de usuarios. Os usuarios compartilharao esta quota. Este tipo de politica de impressao, tambem eh utilizada quando se estipula uma quantidade de paginas a um projeto (o projeto eh denomidado grupo).","GRUPOP","grupop.pl","grupop",1,1,1,"Valcir C.","valcir@unicamp.br");

CREATE TABLE usuario (
  cod_usuario INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  cod_grupo INTEGER UNSIGNED NOT NULL,
  login VARCHAR(50) NOT NULL,
  PRIMARY KEY(cod_usuario),
  UNIQUE INDEX idx_loginUnico(login),
  INDEX usuario_FKIndex1(cod_grupo)
);

CREATE TABLE grupop (
 cod_grupop INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
 cod_grupo  INTEGER UNSIGNED NOT NULL,
 quota      FLOAT,
 cod_politica INTEGER,
 PRIMARY KEY(cod_grupop),
 INDEX grupop_FKIndex1(cod_grupo)
);
