package grava_log;

use strict;
use warnings;
use Carp;

use FileHandle;
use Data::Dumper;

our $VERSION	= '0.01';

# Parametros defaults 
my %fields =(
	log_file	=> '/var/log/ibquota2.log',
	prog	=> 'IBQuota 2',
);

sub new
{            
    my ($proto,%options) = @_;
    my $class = ref($proto) || $proto;
    my $self = {%fields};
    while (my ($key,$value) = each(%options)) {
        if (exists($fields{$key})) {
            $self->{$key} = $value if (defined $value);
        } else {
            die ref($class) . "Opco invlida (class new): '$key'\n";
        }
    }
    foreach (keys(%fields)) {
    	die ref($class) . " necessrio um valor para $_ (class new)" 
    		if (!defined $self->{$_});
    }
    bless $self, $class;
    $self->_init;
    return $self;
}

sub _init {
	my $self = shift;
	$self->{fh} = new FileHandle ">>$self->{log_file}";
	$self->{fh}->autoflush(1);
	die "Impossivel escrever em $self->{log_file}" if (!defined $self->{fh});
}

sub DESTROY {
	my $self = shift;
	$self->{fh}->close;
	undef $self->{fh};
}

sub log {
	my $self = shift;
	my %log_data = @_;
	my $timestamp	= localtime;
	my $sep	= '';	#separador
	my $log_data = $log_data{'message'} if (exists $log_data{'message'}); 
	my $type = '';
	$type = $log_data{'type'} if (exists $log_data{'type'});
	my $print_data	=<<EOF;
[$timestamp] $self->{prog}: $type $log_data
EOF
	$self->{fh}->print($print_data);
}

sub mask { my $s = shift; if (@_) { $s->{mask} = shift; } return $s->{mask}; }

=head1 NOME

grava_log - utilizado para gravar os logs do IBQuota 2

=head2 PARAMETROS

log_file - o path + nome do log_file de log. 

type - tipo de resultado. (ex: erro, ok, etc).

=head2 METODOS PUBLICOS

log( message => $message )

    Adiciona ao log a mensagem.

=head1 OBSERVACAO

    Baseado no modulo Log::FileSimple de autoria de Emiliano Bruni, <info@ebruni.it>.

    Rodrigo Zadra Armond. 2004-06-08

=cut
